import core
import os
import urllib.request
import addonHandler
import globalPluginHandler
import gui
import wx
import datetime
from logHandler import log
import config
import globalVars
import ui
confSpecs = {
	"nbSemaine": "integer(default=60)",
	"autoUpdate": "boolean(default=True)",
	"updateEveryStart": "boolean(default=False)",
}
config.conf.spec["Calsci"] = confSpecs
time=datetime.datetime.now()
week= int(time.strftime("%W"))
baseDir = os.path.dirname(__file__) 
addon = os.path.join(baseDir, "..") 
addonInfos = addonHandler.Addon(addon).manifest
sitename="mbn"
configSectionName="Calsci"

def updateAvailable():
	title = "Mise à jour de {addonname} version {oversion}".format(
		addonname=addonInfos["summary"],
		oversion=oversion)
	msg = "{addonname} version {oversion} est disponible. Souhaitez-vous la mettre à jour maintenant? Vous pourrez voir les nouveautés en cliquant sur le bouton aide dans le gestionnaire d'extension.".format(
		addonname=addonInfos["summary"],
		oversion=oversion)
	res = gui.messageBox(msg, title, wx.YES_NO|wx.ICON_ERROR)
	if res == wx.YES:
		installupdate()
	else:
		config.conf["Calsci"]["nbSemaine"] = week

def installupdate():
	temp=os.environ.get('TEMP')
	file=f"{temp}\calsci_{oversion}.nvda-addon"
	urllib.request.urlopen("https://module.nael-accessvision.com/addons/addons/calsci/compteur.php")
	url=f"https://module.nael-accessvision.com/addons/addons/calsci/calsci_{oversion}.nvda-addon"
	urllib.request.urlretrieve(url, file)
	curAddons = []
	for addon in addonHandler.getAvailableAddons():
		curAddons.append(addon)
	bundle = addonHandler.AddonBundle(file)
	prevAddon = None
	bundleName = bundle.manifest['name']
	for addon in curAddons:
		if not addon.isPendingRemove and bundleName == addon.manifest["name"]:
			prevAddon = addon
			break
	if prevAddon:
		prevAddon.requestRemove()
	addonHandler.installAddonBundle(bundle)
	os.remove(file)
	config.conf["Calsci"]["nbSemaine"] = week
	core.restart()

def verifUpdate(gesture=False):
	global oversion
	version = addonInfos["version"]
	rversion = urllib.request.urlopen("https://module.nael-accessvision.com/addons/addons/calsci/version_calsci.txt")
	tversion = rversion.read().decode()
	oversion=tversion.replace("\n", "")
	if version != oversion:
		wx.CallAfter(updateAvailable)
	else:
		if gesture:
			ui.message("Aucune mise à jour n'est disponible.")

def modeDevParam(param,message):
	if not config.conf[configSectionName][param]:
		config.conf[configSectionName][param]= True
		ui.message(f"{message} est activée.")
	else:
		config.conf[configSectionName][param] = False
		ui.message(f"{message} est désactivée.")

if not globalVars.appArgs.secure and config.conf["Calsci"]["autoUpdate"] and (config.conf["Calsci"]["nbSemaine"] != week or config.conf["Calsci"]["updateEveryStart"]):
	verifUpdate()

class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	scriptCategory = "Calsci"
	def script_gestureUpdate(self, gesture):
		verifUpdate(True)
	
	def script_autoUpdate(self, gesture):
		modeDevParam("autoUpdate","La mise à jour automatique")

	__gestures={
		"kb:nvda+alt+C": "gestureUpdate",
		"kb:nvda+alt+shift+C": "autoUpdate",
	}
	script_gestureUpdate.__doc__ = """Calsci: Rechercher une mise à jour du module manuellement"""
	script_autoUpdate.__doc__ = """Calsci: Active/désactive la recherche de mise à jour automatique"""
